summaryrefslogtreecommitdiff
path: root/libs/pbd/stateful.cc
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2010-08-25 17:32:08 +0000
committerCarl Hetherington <carl@carlh.net>2010-08-25 17:32:08 +0000
commitf30402d073aeae5d24462416407e73d1e0314e71 (patch)
tree62e89b0549125dc8d0d5ee91fe2cc689990b7f08 /libs/pbd/stateful.cc
parent21855b71d2eb8006fda96aefacfa60140ae747d3 (diff)
clear_history -> clear_changes and some comments.
git-svn-id: svn://localhost/ardour2/branches/3.0@7685 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/pbd/stateful.cc')
-rw-r--r--libs/pbd/stateful.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/libs/pbd/stateful.cc b/libs/pbd/stateful.cc
index 204e62685e..8411dc4e60 100644
--- a/libs/pbd/stateful.cc
+++ b/libs/pbd/stateful.cc
@@ -157,12 +157,12 @@ Stateful::instant_xml (const string& str, const sys::path& directory_path)
return 0;
}
/** Forget about any old state for this object */
void
-Stateful::clear_history ()
+Stateful::clear_changes ()
{
for (OwnedPropertyList::iterator i = _properties->begin(); i != _properties->end(); ++i) {
- i->second->clear_history ();
+ i->second->clear_changes ();
}
}
@@ -329,7 +329,7 @@ Stateful::property_factory (const XMLNode& history_node) const
PropertyList* prop_list = new PropertyList;
for (OwnedPropertyList::const_iterator i = _properties->begin(); i != _properties->end(); ++i) {
- PropertyBase* prop = i->second->maybe_clone_self_if_found_in_history_node (history_node);
+ PropertyBase* prop = i->second->clone_from_xml (history_node);
if (prop) {
prop_list->add (prop);
@@ -348,10 +348,10 @@ Stateful::rdiff (vector<StatefulDiffCommand*>& cmds) const
}
void
-Stateful::clear_owned_history ()
+Stateful::clear_owned_changes ()
{
for (OwnedPropertyList::iterator i = _properties->begin(); i != _properties->end(); ++i) {
- i->second->clear_owned_history ();
+ i->second->clear_owned_changes ();
}
}
@@ -157,12 +157,12 @@ Stateful::instant_xml (const string& str, const sys::path& directory_path)
return 0;
}
-/** Forget about any old state for this object */
+/** Forget about any changes to this object's properties */
void